@@ -683,7 +683,7 @@ specifyMarks <- R6::R6Class(classname = 'specifyMarks', lock_objects = FALSE, cl
   #' @param sharedSpatial Logical: specify the shared spatial field in the model. Requires \code{pointsSpatial == 'shared'} in \code{\link{intModel}}. Defaults to \code{FALSE}.
   #' @param datasetName Name of which of the datasets' spatial fields to be specified. Requires \code{pointsSpatial = 'individual'} in \code{\link{intModel}}.
   #' @param Mark Name of the marks to specify the spatial field for. If \code{TRUE} changes the spatial effect for all marks.
-  #' @param Bias Name of the dataset for which the bias field to be specified.
+  #' @param Bias Logical: specify the spatial field for the bias effect. If seperate fields are specified for different fields, the argument may be the name of the dataset for which the bias field to be specified.
   #' @param PC Logical: should the Matern model be specified with pc priors. Defaults to \code{TRUE}, which uses \code{\link[INLA]{inla.spde2.pcmatern}} to specify the model; otherwise uses \code{\link[INLA]{inla.spde2.matern}}.
   #' @param Remove Logical: should the chosen spatial field be removed. Requires one of \code{sharedSpatial}, \code{species}, \code{mark} or \code{bias} to be non-missing, which chooses which field to remove.
   #' @param ... Additional arguments used by \pkg{INLA}'s \code{\link[INLA]{inla.spde2.pcmatern}} or \code{\link[INLA]{inla.spde2.matern}} function, dependent on the value of \code{PC}.
@@ -1370,6 +1370,11 @@ specifyMarks$set('public', 'initialize',  function(data,coordinates,
     else ips <- st_transform(fmesher::fm_int(domain = Inlamesh), projection)
     
     
+  } else {
+    
+    if (!inherits(ips, 'sf')) stop('IPS needs to be a sf object.')
+    if (!'weight' %in% names(ips)) stop('Weight needs to be a name in IPS.')
+    
   }
   
   st_geometry(ips) <- 'geometry'
@@ -1552,7 +1557,7 @@ specifyMarks$set('private', 'addData', function(dataList, responseCounts, respon
                    
                    ##Add here that if markSpatial then add mark_spatial
                    #Also add markModel in the initial call.
-                   pointData$makeFormulas(spatcovs = private$spatcovsNames, speciesname = speciesName, temporalname = private$temporalName,
+                   pointData$makeFormulas(spatcovs = private$spatcovsNames, spatcovclass = NULL, speciesname = speciesName, temporalname = private$temporalName,
                                           paresp = responsePA, countresp = responseCounts, marksspatial = private$marksSpatial, speciesintercept = private$speciesIntercepts, 
                                           marks = markNames, spatial = private$Spatial, speciesindependent = private$speciesIndependent, speciesenvironment = private$speciesEnvironment,
                                           intercept = private$Intercepts, markintercept = private$marksIntercepts, speciesspatial = private$speciesSpatial, biasformula = private$biasFormula,
@@ -1807,8 +1812,7 @@ specifyMarks$set('private', 'spatialCovariates', function(spatialCovariates) {
   } 
   else spatcovsEnv <- parent.frame()
   
-  if (!class(spatialCovariates) %in% c('SpatRaster',
-                                       'SpatialPixelsDataFrame')) stop('The spatial Covariates need to be a spatRaster object or a SpatialPixelsDataFrame.')
+  if (!class(spatialCovariates) %in% c('SpatRaster')) stop('The spatial Covariates need to be a spatRaster object.')
   
   spatcovsIncl <- names(spatialCovariates)
   
